@@ -166,7 +166,7 @@ def do_add(
         requirements[key] = r
     stream.echo(
         f"Adding packages to {section} dependencies: "
-        + ", ".join(str(stream.green(key, bold=True)) for key in requirements)
+        + ", ".join(stream.green(key or "", bold=True) for key in requirements)
     )
     all_dependencies = project.all_dependencies
     all_dependencies.setdefault(section, {}).update(requirements)
@@ -481,7 +481,7 @@ def do_info(
 ) -> None:
     """Show project information."""
     check_project_file(project)
-    python_path = project.environment.python_executable
+    python_path = project.python_executable
     python_version, is_64bit = get_python_version(python_path, True)
     if not python and not show_project and not env:
         rows = [
