@@ -1,6 +1,8 @@
 from __future__ import annotations
 
+import argparse
 import importlib
+import os
 import pkgutil
 import sys
 from typing import Optional, Type
@@ -11,7 +13,7 @@ from resolvelib import Resolver
 
 from pdm.cli.actions import migrate_pyproject, print_pep582_command
 from pdm.cli.commands.base import BaseCommand
-from pdm.cli.options import pep582_option, verbose_option
+from pdm.cli.options import ignore_python_option, pep582_option, verbose_option
 from pdm.cli.utils import PdmFormatter, PdmParser
 from pdm.installers import Synchronizer
 from pdm.iostream import stream
@@ -58,6 +60,7 @@ class Core:
             help="show the version and exit",
         )
         verbose_option.add_to_parser(self.parser)
+        ignore_python_option.add_to_parser(self.parser)
         pep582_option.add_to_parser(self.parser)
 
         self.subparsers = self.parser.add_subparsers()
@@ -72,6 +75,29 @@ class Core:
     def __call__(self, *args, **kwargs):
         return self.main(*args, **kwargs)
 
+    def ensure_project(
+        self, options: argparse.Namespace, obj: Optional[Project]
+    ) -> None:
+        if obj is not None:
+            options.project = obj
+        if getattr(options, "project", None) is None:
+            project = None
+            global_project = getattr(options, "global_project", None)
+            if global_project is True:
+                project_factory = self.project_class.create_global
+            elif global_project:
+                project = global_project
+            else:
+                project_factory = self.project_class
+
+            if project is None:
+                project = project_factory(getattr(options, "project_path", None))
+            options.project = project
+
+        # Add reverse reference for core object
+        options.project.core = self
+        migrate_pyproject(options.project)
+
     def main(self, args=None, prog_name=None, obj=None, **extra):
         """The main entry function"""
         from pdm.models.pip_shims import global_tempdir_manager
@@ -79,23 +105,16 @@ class Core:
         self.init_parser()
         self.load_plugins()
 
-        self.parser.set_defaults(global_project=None)
         options = self.parser.parse_args(args or None)
         stream.set_verbosity(options.verbose)
+        if options.ignore_python:
+            os.environ["PDM_IGNORE_SAVED_PYTHON"] = "1"
 
-        if obj is not None:
-            options.project = obj
-        if options.global_project:
-            options.project = options.global_project
         if options.pep582:
             print_pep582_command(options.pep582)
             sys.exit(0)
-        if not getattr(options, "project", None):
-            options.project = self.project_class()
 
-        # Add reverse reference for core object
-        options.project.core = self
-        migrate_pyproject(options.project)
+        self.ensure_project(options, obj)
 
         try:
             f = options.handler
