@@ -4,8 +4,13 @@ from pathlib import Path
 import tomlkit
 import tomlkit.exceptions
 
-from pdm.formats.base import MetaConverter, convert_from
-from pdm.models.requirements import parse_requirement
+from pdm.formats.base import (
+    MetaConverter,
+    array_of_inline_tables,
+    convert_from,
+    make_array,
+    make_inline_table,
+)
 
 
 def check_fingerprint(project, filename):
@@ -21,8 +26,7 @@ def check_fingerprint(project, filename):
 def _get_author(metadata, type_="author"):
     name = metadata.pop(type_)
     email = metadata.pop(f"{type_}-email", None)
-    email = f" <{email}>" if email else ""
-    return f"{name}{email}"
+    return array_of_inline_tables([{"name": name, "email": email}])
 
 
 class FlitMetaConverter(MetaConverter):
@@ -44,40 +48,29 @@ class FlitMetaConverter(MetaConverter):
         )[0]
         # author and maintainer
         if "author" in metadata:
-            self._data["author"] = _get_author(metadata)
+            self._data["authors"] = _get_author(metadata)
         if "maintainer" in metadata:
-            self._data["maintainer"] = _get_author(metadata, "maintainer")
+            self._data["maintainers"] = _get_author(metadata, "maintainer")
+        if "license" in metadata:
+            self._data["license"] = make_inline_table({"text", metadata.pop("license")})
+            self._data["dynamic"] = ["classifiers"]
         if "urls" in metadata:
-            self._data["project_urls"] = metadata.pop("urls")
+            self._data["urls"] = metadata.pop("urls")
         if "home-page" in metadata:
-            self._data["homepage"] = metadata.pop("home-page")
+            self._data.setdefault("urls", {})["homepage"] = metadata.pop("home-page")
         if "description-file" in metadata:
             self._data["readme"] = metadata.pop("description-file")
         if "requires-python" in metadata:
-            self._data["python_requires"] = metadata.pop("requires-python")
+            self._data["requires-python"] = metadata.pop("requires-python")
+            self._data["dynamic"] = ["classifiers"]
         # requirements
-        self._data["dependencies"] = dict(
-            parse_requirement(line).as_req_dict()
-            for line in metadata.pop("requires", [])
-        )
-        extra_reqs = metadata.pop("requires-extra", {})
-        extras = []
-        for key, reqs in extra_reqs.items():
-            extras.append(key)
-            self._data[f"{key}-dependencies"] = dict(
-                parse_requirement(line).as_req_dict() for line in reqs
-            )
-        if extras:
-            self._data["extras"] = extras
+        self._data["dependencies"] = make_array(metadata.pop("requires", []), True)
+        self._data["optional-dependencies"] = metadata.pop("requires-extra", {})
         # Add remaining metadata as the same key
         self._data.update(metadata)
         return self._data["name"]
 
-    @convert_from("scripts")
-    def cli(self, value):
-        return value
-
-    @convert_from("entrypoints")
+    @convert_from("entrypoints", name="entry-points")
     def entry_points(self, value):
         return value
 
@@ -89,8 +82,9 @@ class FlitMetaConverter(MetaConverter):
 
 def convert(project, filename):
     with open(filename, encoding="utf-8") as fp:
-        return dict(
-            FlitMetaConverter(tomlkit.parse(fp.read())["tool"]["flit"], filename)
+        return (
+            dict(FlitMetaConverter(tomlkit.parse(fp.read())["tool"]["flit"], filename)),
+            {},
         )
 
 
