@@ -182,11 +182,11 @@ class EnvBuilder:
         """
         python_version, _ = get_python_version(self.executable)
         proc = subprocess.run(
-            [self.executable, "-m", "pip", "--version"], capture_output=True
+            [self.executable, "-Im", "pip", "--version"], capture_output=True
         )
         if proc.returncode == 0:
             # The pip has already been installed with the executable, just use it
-            return [self.executable, "-m", "pip"]
+            return [self.executable, "-Im", "pip"]
         if python_version[0] == 3:
             # Use the ensurepip to provision one.
             try:
@@ -196,7 +196,7 @@ class EnvBuilder:
             except BuildError:
                 pass
             else:
-                return [self.executable, "-m", "pip"]
+                return [self.executable, "-Im", "pip"]
         # Otherwise, download a pip wheel from the Internet.
         pip_wheel = self._env.project.cache_dir / "pip.whl"
         if not pip_wheel.is_file():
@@ -265,7 +265,7 @@ class EnvBuilder:
         setup_py_path = builder.ensure_setup_py().as_posix()
         self.install(["setuptools"])
         args = [self.executable, "-c", _SETUPTOOLS_SHIM.format(setup_py_path)]
-        args.extend(["egg_info", "--egg-base", out_dir])
+        args.extend(["egg_info", "--egg-base", os.path.relpath(out_dir, self.src_dir)])
         self.subprocess_runner(args, cwd=self.src_dir)
         filename = _find_egg_info(out_dir)
         return os.path.join(out_dir, filename)
